package Mythic::SSHAPI::Response;

use strict;

use JSON;

sub new {
    my $class = shift;
    my ($payload, $error, $status) = @_;
    my $self = {};
    $self->{stderr} = $error;
    $self->{exit_code} = $status;

    if ($status != 0) {
        $self->{error} = {
            code => 500,
            message => "Command returned non-zero exit code ($status)",
        };
    }
    else {
            
        my $data = eval { decode_json($payload); };
        if(!defined($data)) {
            $self->{error} = { message => "Error decoding JSON response" };
            $self->{content} = {};
        }
        else {
            if ($data->{error}) {
                $self->{error} = $data->{error};
            }
            $self->{content} = $data->{content};
        }
    }

    bless $self, $class;
    return $self;
}

sub success {
    my $self = shift;
    return $self->{error} ? 0 : 1;
}

sub error {
    my $self = shift;
    return $self->{error}->{message};
}

sub content {
    my $self = shift;
    return $self->{content};
}

sub stderr {
    my $self = shift;
    return $self->{stderr};
}

sub exit_code {
    my $self = shift;
    return $self->{exit_code};
}



1;
